# Web Analyser
Analyses Websites for you. It can grab a limited amount of things (for now), but it's better than doing them manually:

* Robots and Sitemap
* Cookies
* Redirects
* Comments
* URLs in the source
* Resources in the source, e.g. `/api/v2`
* Differences between User-Agents

Also supports the use of a custom User-Agent

# Installing
```
git clone https://github.com/ir0nstone/web-analyser.git
cd web-analyser
pip3 install -r requirements.txt
```